@@ -1,47 +1,51 @@
-const TARGET_EXE_PATH: &'static str = env!("CARGO_BIN_EXE_aki-resort");
+const TARGET_EXE_PATH: &'static str = env!(concat!("CARGO_BIN_EXE_", env!("CARGO_PKG_NAME")));
 
 macro_rules! help_msg {
     () => {
         concat!(
             version_msg!(),
             "\n",
-            "Usage:\n",
-            "  aki-resort [options]\n",
-            "\n",
-            "sort lines of text.\n",
-            "\n",
-            "Ordering options:\n",
-            "  -r, --reverse                 reverse the result of comparisons\n",
-            "      --according-to <word>     sort according to <word>\n",
-            "  -h, --head <num>              unsort the first <num> lines.\n",
-            "  -t, --tail <num>              unsort the last <num> lines.\n",
-            "\n",
-            "Other options:\n",
-            "      --color <when>            use markers to highlight the matching strings\n",
-            "  -e, --exp <exp>               regular expression. sort by the entires match\n",
-            "  -u, --unique                  output only the first line of an equal\n",
-            "      --max-buffer <size>       max buffer size\n",
-            "\n",
-            "  -H, --help        display this help and exit\n",
-            "  -V, --version     display version information and exit\n",
-            "  -X <x-options>    x options. try -X help\n",
-            "\n",
-            "Option Parameters:\n",
-            "  <word>    'string', 'numeric', 'month', 'version'\n",
-            "  <when>    'always', 'never', or 'auto'\n",
-            "  <exp>     regular expression, sort by the entires match.\n",
-            "  <size>    if a reading size is more than <size>, then it is not output,\n",
-            "            quit and display error message.\n",
-            "\n",
-            "Environments:\n",
-            "  AKI_RESORT_COLOR_SEQ_ST   color start sequence specified by ansi\n",
-            "  AKI_RESORT_COLOR_SEQ_ED   color end sequence specified by ansi\n",
-            "\n",
-            "Examples:\n",
-            "  This sort via utf-8 code:\n",
-            "    cat file1.txt | aki-resort\n",
-            "  This sort via 1st chunk of numeric character according to numeric:\n",
-            "    cat file1.txt | aki-resort -e \"[0-9]+\" --according-to numeric\n",
+            indoc::indoc!(
+                r#"
+            Usage:
+              aki-resort [options]
+
+            sort lines of text.
+
+            Ordering options:
+              -r, --reverse                 reverse the result of comparisons
+                  --according-to <word>     sort according to <word>
+              -h, --head <num>              unsort the first <num> lines.
+              -t, --tail <num>              unsort the last <num> lines.
+
+            Other options:
+                  --color <when>            use markers to highlight the matching strings
+              -e, --exp <exp>               regular expression. sort by the entires match
+              -u, --unique                  output only the first line of an equal
+                  --max-buffer <size>       max buffer size
+
+              -H, --help        display this help and exit
+              -V, --version     display version information and exit
+              -X <x-options>    x options. try -X help
+
+            Option Parameters:
+              <word>    'string', 'numeric', 'month', 'version'
+              <when>    'always', 'never', or 'auto'
+              <exp>     regular expression, sort by the entires match.
+              <size>    if a reading size is more than <size>, then it is not output,
+                        quit and display error message.
+
+            Environments:
+              AKI_RESORT_COLOR_SEQ_ST   color start sequence specified by ansi
+              AKI_RESORT_COLOR_SEQ_ED   color end sequence specified by ansi
+
+            Examples:
+              This sort via utf-8 code:
+                cat file1.txt | aki-resort
+              This sort via 1st chunk of numeric character according to numeric:
+                cat file1.txt | aki-resort -e "[0-9]+" --according-to numeric
+            "#
+            ),
             "\n",
         )
     };
@@ -116,10 +120,8 @@ Cherry:4:4:good:Oct
 Kiwi:1111:1.1.11:good:Jun
 ";
 
-mod helper;
-
 mod test_0 {
-    use crate::helper::exec_target;
+    use exec_target::exec_target;
     const TARGET_EXE_PATH: &'static str = super::TARGET_EXE_PATH;
     //
     #[test]
@@ -171,7 +173,7 @@ mod test_0 {
 }
 
 mod test_string {
-    use crate::helper::exec_target_with_in;
+    use exec_target::exec_target_with_in;
     const TARGET_EXE_PATH: &'static str = super::TARGET_EXE_PATH;
     //
     #[test]
@@ -317,7 +319,7 @@ mod test_string {
 }
 
 mod test_string_color {
-    use crate::helper::exec_target_with_env_in;
+    use exec_target::exec_target_with_env_in;
     const TARGET_EXE_PATH: &'static str = super::TARGET_EXE_PATH;
     //
     #[test]
@@ -485,7 +487,7 @@ mod test_string_color {
 }
 
 mod test_numeric {
-    use crate::helper::exec_target_with_in;
+    use exec_target::exec_target_with_in;
     const TARGET_EXE_PATH: &'static str = super::TARGET_EXE_PATH;
     //
     #[test]
@@ -635,7 +637,7 @@ mod test_numeric {
 }
 
 mod test_numeric_color {
-    use crate::helper::exec_target_with_env_in;
+    use exec_target::exec_target_with_env_in;
     const TARGET_EXE_PATH: &'static str = super::TARGET_EXE_PATH;
     //
     #[test]
@@ -839,7 +841,7 @@ mod test_numeric_color {
 }
 
 mod test_version {
-    use crate::helper::exec_target_with_in;
+    use exec_target::exec_target_with_in;
     const TARGET_EXE_PATH: &'static str = super::TARGET_EXE_PATH;
     //
     #[test]
@@ -853,7 +855,7 @@ mod test_version {
             oup.stderr,
             concat!(
                 program_name!(),
-                ": (0,21):\'Apple:33:3.3:good:Mar\': lexer error: UnexpectedChar(\':\')\n",
+                ": (0,21):\'Apple:33:3.3:good:Mar\': unexpected character \'A\' while parsing major version number\n",
             )
         );
         assert_eq!(oup.stdout, "");
@@ -871,7 +873,7 @@ mod test_version {
             oup.stderr,
             concat!(
                 program_name!(),
-                ": (0,21):\'Apple:33:3.3:good:Mar\': lexer error: UnexpectedChar(\':\')\n",
+                ": (0,21):\'Apple:33:3.3:good:Mar\': unexpected character \'A\' while parsing major version number\n",
             )
         );
         assert_eq!(oup.stdout, "");
@@ -1009,7 +1011,7 @@ mod test_version {
 }
 
 mod test_version_color {
-    use crate::helper::exec_target_with_env_in;
+    use exec_target::exec_target_with_env_in;
     const TARGET_EXE_PATH: &'static str = super::TARGET_EXE_PATH;
     //
     #[test]
@@ -1025,7 +1027,7 @@ mod test_version_color {
             oup.stderr,
             concat!(
                 program_name!(),
-                ": (0,21):\'Apple:33:3.3:good:Mar\': lexer error: UnexpectedChar(\':\')\n",
+                ": (0,21):\'Apple:33:3.3:good:Mar\': unexpected character \'A\' while parsing major version number\n",
             )
         );
         assert_eq!(oup.stdout, "");
@@ -1045,7 +1047,7 @@ mod test_version_color {
             oup.stderr,
             concat!(
                 program_name!(),
-                ": (0,21):\'Apple:33:3.3:good:Mar\': lexer error: UnexpectedChar(\':\')\n",
+                ": (0,21):\'Apple:33:3.3:good:Mar\': unexpected character \'A\' while parsing major version number\n",
             )
         );
         assert_eq!(oup.stdout, "");
@@ -1213,7 +1215,7 @@ mod test_version_color {
 }
 
 mod test_month {
-    use crate::helper::exec_target_with_in;
+    use exec_target::exec_target_with_in;
     const TARGET_EXE_PATH: &'static str = super::TARGET_EXE_PATH;
     //
     #[test]
@@ -1363,7 +1365,7 @@ mod test_month {
 }
 
 mod test_month_color {
-    use crate::helper::exec_target_with_env_in;
+    use exec_target::exec_target_with_env_in;
     const TARGET_EXE_PATH: &'static str = super::TARGET_EXE_PATH;
     //
     #[test]
@@ -1567,8 +1569,8 @@ mod test_month_color {
 }
 
 mod test_2 {
-    use crate::helper::exec_target_with_env_in;
-    use crate::helper::exec_target_with_in;
+    use exec_target::exec_target_with_env_in;
+    use exec_target::exec_target_with_in;
     const TARGET_EXE_PATH: &'static str = super::TARGET_EXE_PATH;
     //
     #[test]
@@ -1628,7 +1630,7 @@ mod test_2 {
 }
 /*
 mod test_3 {
-    use crate::helper::exec_target;
+    use exec_target::exec_target;
     const TARGET_EXE_PATH: &'static str = super::TARGET_EXE_PATH;
     //
     #[test]
@@ -1647,7 +1649,7 @@ mod test_3 {
 */
 /*
 mod test_4 {
-    use crate::helper::exec_target_with_in;
+    use exec_target::exec_target_with_in;
     //use exec_target::args_from;
     const TARGET_EXE_PATH: &'static str = super::TARGET_EXE_PATH;
 
